struct CookieBeginReply {
cookie_auth: ObjectId,
server_addr: String,
server_mac: CookieAuthMac,
server_nonce: CookieAuthNonce,
}Expand description
An RPC server’s response to an auth:cookie_begin request.
Fields
Handle to an object to use for the client’s subsequent cookie_continue.
server_addr: StringThe address that the server believes it is listening on.
The client should verify that this is the exact string encoded in the connect point that it’s trying to use.
server_mac: CookieAuthMacA MAC proving that the server knows the secret cookie.
32 bytes long, encoded in 64 bytes of hexadecimal. Case-insensitive.
server_nonce: CookieAuthNonceA secret nonce chosen by the server.
32 bytes long, encoded in 64 bytes of hexadecimal. Case-insensitive.