struct Authenticate {
scheme: AuthenticationScheme,
}Expand description
Authenticate on an RPC Connection, returning a new Session.
After connecting to Arti, clients use this method to create a Session, which they then use to access other functionality.
This method supports simple authentication schemes,
where only a single pass is necessary to open a session.
For now, only the auth:inherent scheme is supported here;
other schemes will be implemented in the future.
See also the auth:begin_cookie method.
You typically won’t need to invoke this method yourself;
instead, your RPC library (such as arti-rpc-client-core)
should handle it for you.
Fields
scheme: AuthenticationSchemeThe authentication scheme as enumerated in the spec.
The only supported one for now is “auth:inherent”