pub(crate) enum CancelError {
RequestNotFound,
CannotCancelRequest,
AlreadyCancelled,
}Expand description
An error given when we attempt to cancel an RPC request, but cannot.
Variants
RequestNotFound
We didn’t find any request with the provided ID.
Since we don’t keep track of requests after they finish or are cancelled, we cannot distinguish the cases where a request has finished, where the request has been cancelled, or where the request never existed. Therefore we collapse them into a single error type.
CannotCancelRequest
This kind of request cannot be cancelled.
AlreadyCancelled
We tried to cancel a request but found out it was already cancelled.
This error should be impossible.