struct MissingFeaturesError(Vec<String>);Expand description
An error returned when an RPC request lists some feature as required, but we don’t have every such feature.
Tuple Fields
0: Vec<String>A list of the features that were requested but not available.