pub enum RequestParseError {
IdMissing,
IdType,
ObjMissing,
ObjType,
MethodMissing,
MethodType,
MetaType,
NoSuchMethod,
ParamType,
MissingParams,
}Expand description
An error encountered while parsing an RPC request, that we will report to the client.
Note that this does not include fatal parsing errors that result in closing the connection entirely.
Variants
IdMissing
The id field was missing.
IdType
The id field did not have the expected type (integer or string).
ObjMissing
The obj field was missing.
ObjType
The method field did not have the expected type (string).
MethodMissing
The method field was missing.
MethodType
The method field did not have the expected type (string).
MetaType
The meta field was present, but it could not be parsed.
Maybe it was not a json object; maybe it had a field of the wrong type.
NoSuchMethod
The method field was not the name of any recognized method.
ParamType
The parameters were of the wrong type for the method.
MissingParams
The params field was missing.