pub fn rpc_methods<R: Runtime>() -> Vec<InvokerEnt>Expand description
Return a list of RPC methods that will be needed to use arti-rpcserver with the given runtime.
pub fn rpc_methods<R: Runtime>() -> Vec<InvokerEnt>Return a list of RPC methods that will be needed to use arti-rpcserver with the given runtime.