GlobalId

Struct GlobalId 

pub(crate) struct GlobalId {
    pub(crate) connection: ConnectionId,
    pub(crate) local_id: GenIdx,
}
A RpcMgr-scoped identifier for an RPC object.

A GlobalId identifies an RPC object uniquely among all the objects visible to any active session on an RpcMgr.

Its encoding is unforgeable.

Fields

connection: ConnectionId

The RPC connection within whose object map local_id is visible.

local_id: GenIdx

The identifier of the object within connection’s object map.

Implementations

Source

impl GlobalId

const ENCODED_LEN: usize

The number of bytes used to encode a GlobalId in binary form.

const TAG_CHAR: char = '$'

A prefix we use when encoding global IDs in base64.

Since this isn’t a valid base 64 character, we can’t confuse it with a base64 string.

pub(crate) fn new(connection: ConnectionId, local_id: GenIdx) -> GlobalId

Create a new GlobalId from its parts.

pub(crate) fn encode(&self, key: &MacKey) -> ObjectId

Encode this ID in an unforgeable string that we can later use to uniquely identify an RPC object.

As with local IDs, this encoding is nondeterministic.

fn encode_as_bytes<R: RngCore>(&self, key: &MacKey, rng: &mut R) -> Vec<u8>

As encode, but do not base64-encode the result.

pub(crate) fn try_decode( key: &MacKey, s: &ObjectId, ) -> Result<Option<Self>, LookupError>

Try to decode and validate s as a GlobalId.

Returns Ok(None) if s is not tagged as an identifier for a GlobalId.

fn try_decode_from_bytes(key: &MacKey, bytes: &[u8]) -> Option<Self>

As try_decode, but expect a byte slice rather than a base64-encoded string.