pub(crate) struct Inner {
connections: WeakValueHashMap<ConnectionId, Weak<Connection>, RandomState>,
}Expand description
The RpcMgr’s state. This is kept inside a lock for interior mutability.
Lock hierarchy
This system has, relevantly to the RPC code, three locks. In order from outermost (acquire earlier) to innermost (acquire later):
Connection.innerRpcMgr.innerRwLock<rpc::DispatchTable>(found inRpcMgr.dispatch_tableandConnection.dispatch_table)
To avoid deadlock, when more than one of these locks is acquired, they must be acquired in an order consistent with the order listed above.
(This ordering is slightly surprising: normally a lock covering more-global state would be “outside” (or “earlier”) compared to one covering more-narrowly-relevant state.)
Fields
connections: WeakValueHashMap<ConnectionId, Weak<Connection>, RandomState>A map from ConnectionId to weak Connection references.
We use this map to give connections a manager-global identifier that can be used to identify them from a SOCKS connection (or elsewhere outside of the RPC system).
We could use a generational arena here, but there isn’t any point: since these identifiers are global, we need to keep them secure by MACing anything derived from them, which in turn makes the overhead of a HashMap negligible.