type ObjectWithContext = (Arc<dyn Context>, Arc<dyn Object>);Expand description
An rpc::Object, along with its associated rpc::Context.
The context can be used to invoke any special methods on the object.
type ObjectWithContext = (Arc<dyn Context>, Arc<dyn Object>);An rpc::Object, along with its associated rpc::Context.
The context can be used to invoke any special methods on the object.