RpcCloneId

Struct RpcCloneId 

struct RpcCloneId {
    weak: bool,
    release: bool,
}
Return a new object ID referring to an existing object.

This method does not clone the underlying object itself: the new ID as well as the old ID both refer to the same object.

Releases the original object ID if the release flag is true. Otherwise, makes no change to the original object ID.

This method can be used to create a weak ID from a strong ID, or vice versa.

Fields

weak: bool

If true, the new ID should be a weak reference. If false, the new ID should be a strong reference.

Defaults to “false”.

release: bool

If true, the original ID should be dropped.