struct GetSuperuserCapability {}Expand description
Return the superuser capability for a session.
Just as a session is the root object proving that your program has authenticated
Returns an error if this session is not authorized for superuser access,
or if you have dropped superuser access via arti:remove_superuser_permission.