pub struct RpcSession {
client: Arc<dyn Client>,
superuser: Mutex<Option<Arc<dyn Object>>>,
}Expand description
An authenticated RPC session: a capability through which most other RPC functionality is available
This relates to Connection as follows:
-
A
Connectionexists prior to authentication; whereas anRpcSessioncomes into being as a result of authentication. -
The
RpcSessionis principally owned by theConnection’s object table. -
Typically, after authentication, there is one
RpcSessionfor theConnection. But a client may authenticate more than once; each time produces a newRpcSession.
In the arti rpc system
Base type for an authenticated RPC session.
Upon successful authentication via auth:authenticate,
a connection will return either a Session object of this type,
or a Session object that wraps this type.
All other useful objects are available via an RPC session.
This ObjectID for this object can be used as the target of a SOCKS stream.
Fields
client: Arc<dyn Client>An inner TorClient object that we use to implement remaining functionality.
superuser: Mutex<Option<Arc<dyn Object>>>A superuser object representing administrative capability.
If this object is absent, this session never had this capability, or dropped it.
Implementations
Sourceimpl RpcSession
impl RpcSession
Sourcepub fn new_with_client<R: Runtime>(client: Arc<TorClient<R>>) -> Arc<Self>
pub fn new_with_client<R: Runtime>(client: Arc<TorClient<R>>) -> Arc<Self>
Create a new session object containing a single client object.
Sourcepub fn provide_superuser_permission(&self, superuser: Arc<dyn Object>)
pub fn provide_superuser_permission(&self, superuser: Arc<dyn Object>)
Set the superuser object for this session to superuser.
Calling this function indicates that this session has administrative privilege.
Sourcefn client_as_object(&self) -> Arc<dyn Object>
fn client_as_object(&self) -> Arc<dyn Object>
Return a view of the client associated with this session, as an Arc<dyn rpc::Object>.