enum Inner {
Unused(Arc<dyn Object>),
Launching,
Stream(Arc<ClientDataStreamCtrl>),
UsedToResolve,
StreamFailed,
}Expand description
The inner state of an OneshotClient.
A stream is created in the “Unused” state.
Variants
Unused(Arc<dyn Object>)
Newly constructed: Waiting for a SOCKS command.
This is the initial state for every OneshotClient.
It may become Launching or UsedToResolve.
Launching
The actual connection is being made, ie we are within connect_with_prefs
If the state is Launching, no one except connect_with_prefs may change it.
From this state, a stream may become Stream, or StreamFailed.
Stream(Arc<ClientDataStreamCtrl>)
Stream constructed; may or may not be connected.
A stream does not exit this state. Even if the stream is closed or fails,
its ClientDataStreamCtrl remains until it is dropped.
UsedToResolve
Stream was used for a resolve or resolve_ptr request; there is no underlying stream.
A stream does not exit this state, even if resolve request fails.
StreamFailed
Failed to construct the tor_proto::DataStream object.
A stream does not exit this state.