pub(crate) struct OneshotClient {
inner: Mutex<Inner>,
}Expand description
An RPC object representing a single-use client that captures a data-stream.
This object is returned by the arti:new_oneshot_client method, and starts out with
enough information to know how to create a DataStream, or to respond
to some other SOCKS request.
When this object is the target of a SOCKS request,
it takes its target address, port, and isolation parameters from the SOCKS handshake,
and launches a data stream.
It then becomes interchangeable with the stream that was launched.
This object is single-use: once a SOCKS request has referred to it,
it cannot be used for any other SOCKS request.
(Otherwise, it could not be usable interchangeably with the DataStream it creates.)
The ObjectID for this object can be used as the target of a SOCKS request.
Fields
inner: Mutex<Inner>The inner state of this object.
Implementations
Sourceimpl OneshotClient
impl OneshotClient
Sourcepub(crate) fn new(connector: Arc<dyn Object>) -> Self
pub(crate) fn new(connector: Arc<dyn Object>) -> Self
Construct a new unused OneshotClient that will make its connection
with connector.
The connector object should implement at least one of ConnectWithPrefs, ResolveWithPrefs,
or ResolvePtrWithPrefs, or else it won’t actually be useful for anything.
Sourcefn take_connector(
&self,
new_state: Inner,
) -> Result<Arc<dyn Object>, OneshotClientError>
fn take_connector( &self, new_state: Inner, ) -> Result<Arc<dyn Object>, OneshotClientError>
If this OneshotClient is in state Unused, replace its state with new_state
and return the ClientConnectionTarget. Otherwise, leave its state unchanged
and return an error.
Sourcefn get_ctrl(&self) -> Option<Arc<ClientDataStreamCtrl>>
fn get_ctrl(&self) -> Option<Arc<ClientDataStreamCtrl>>
Return the ClientDataStreamCtrl for this stream, if it has one.