pub struct Connection { /* private fields */ }Expand description
An open connection from an RPC client.
Tracks information that persists from one request to another.
The client might not have authenticated;
access and permissions control is handled via the capability system.
Specifically, the objects table in Inner hold capabilities
that the client will use to do things,
including an RpcSession.
In the Arti RPC System
A connection to Arti.
This object is available as soon as you open a connection to Arti RPC,
even before you authenticate. Its ObjectId is always "connection".
Because this object is available before authentication,
it provides only those methods that you need
in order to perform authentication
and receive an RpcSession.
Note that a connection can only be authenticated once:
If you drop the RpcSession returned by authenticating,
you cannot get another one on the same connection.
Implementations
Sourceimpl Connection
impl Connection