pub(crate) struct GlobalId {
pub(crate) connection: ConnectionId,
pub(crate) local_id: GenIdx,
}Expand description
A RpcMgr-scoped identifier for an RPC object.
A GlobalId identifies an RPC object uniquely among all the objects visible
to any active session on an RpcMgr.
Its encoding is unforgeable.
Fields
connection: ConnectionIdThe RPC connection within whose object map local_id is visible.
local_id: GenIdxThe identifier of the object within connection’s object map.
Implementations
Sourceimpl GlobalId
impl GlobalId
Sourceconst ENCODED_LEN: usize
const ENCODED_LEN: usize
The number of bytes used to encode a GlobalId in binary form.
Sourceconst TAG_CHAR: char = '$'
const TAG_CHAR: char = '$'
A prefix we use when encoding global IDs in base64.
Since this isn’t a valid base 64 character, we can’t confuse it with a base64 string.
Sourcepub(crate) fn new(connection: ConnectionId, local_id: GenIdx) -> GlobalId
pub(crate) fn new(connection: ConnectionId, local_id: GenIdx) -> GlobalId
Create a new GlobalId from its parts.
Sourcepub(crate) fn encode(&self, key: &MacKey) -> ObjectId
pub(crate) fn encode(&self, key: &MacKey) -> ObjectId
Encode this ID in an unforgeable string that we can later use to uniquely identify an RPC object.
As with local IDs, this encoding is nondeterministic.
Sourcefn encode_as_bytes<R: RngCore>(&self, key: &MacKey, rng: &mut R) -> Vec<u8> ⓘ
fn encode_as_bytes<R: RngCore>(&self, key: &MacKey, rng: &mut R) -> Vec<u8> ⓘ
As encode, but do not base64-encode the result.
Sourcepub(crate) fn try_decode(
key: &MacKey,
s: &ObjectId,
) -> Result<Option<Self>, LookupError>
pub(crate) fn try_decode( key: &MacKey, s: &ObjectId, ) -> Result<Option<Self>, LookupError>
Try to decode and validate s as a GlobalId.
Returns Ok(None) if s is not tagged as an identifier for a GlobalId.
Sourcefn try_decode_from_bytes(key: &MacKey, bytes: &[u8]) -> Option<Self>
fn try_decode_from_bytes(key: &MacKey, bytes: &[u8]) -> Option<Self>
As try_decode, but expect a byte slice rather than a base64-encoded string.